@@ -3,17 +3,44 @@ import html
 from .. import regex as re_
 from ..data.ingredient_funnel import dictionary as ing_funnel
 import numpy as np
+import unicodedata
+import unidecode
 
 class RecipeReader:
     def __init__(self):
         pass
 
+    def normalize(self, phrase):
+        phrase = unicodedata.normalize('NFD', phrase)
+        phrase = unidecode(phrase)
+        phrase = phrase.lower()
+        phrase = re.sub(r'\([^)]*\)', '', phrase)
+        phrase = re.sub(r'\(|\)', '', phrase)
+        
+        for vulgar_fraction, fraction_str in vf.dictionary.items():
+            phrase = re.sub(vulgar_fraction, ' ' + fraction_str + ' ', phrase)
+        
+        phrase = phrase.replace('–', '-')
+        phrase = phrase.replace('⁄', '/')
+        phrase = re.sub(r'half ?(?:and|-) ?half', 'half-and-half', phrase)
+        phrase = re.sub(r'\.\.+', '', phrase)
+        phrase = re.sub(r' *\. *(?![0-9])', '. ', phrase)
+        phrase = re.sub(r'(?<=[0-9]) *\. *(?=[0-9])', '.', phrase)
+        phrase = re.sub(r" '", "'", phrase)
+        phrase = re.sub(r'(,[^,]+)?< ?a href.*', '', phrase)
+        phrase = re.sub(r'(?<=[a-z])/[a-z]+', '', phrase)
+        phrase = re.sub(r'\b(?:5|five)[- ]?spice', 'fivespice', phrase)
+        phrase = re.sub(r'.*: ?', '', phrase)
+        phrase = re.sub(r'\s+', ' ')
+        phrase = phrase.strip()
+
+
     def read_phrase(self, phrase):
         if not P_filter(phrase):
             return None
 
         phrase = html.unescape(phrase)
-        phrase = normalizer.normalize_str(phrase)
+        phrase = self.normalize(phrase)
         phrase = P_duplicates(phrase)
 
         phrase = P_multi_misc_fix(phrase)
@@ -60,4 +87,4 @@ class RecipeReader:
         return {
             'ingredients': out,
             'values': np.array([1 if c in out else 0 for c in columns])
-        }
\ No newline at end of file
+        }
